# Happy Scientists
Incredible package to generate funny random names

## Installation
To install from download folder:
~~~~~
pip install .
~~~~~

To install through pip
~~~~~
pip install happy-scientists
~~~~~

## Example
~~~~~
from happyscientists import ScientistsGenerator as sg
random_sct = sg.generate_name()
print(random_sct)
~~~~~
